degreeDistribution: Degree Distribution

Description Usage Arguments Value Author(s) References Examples

View source: R/degreeDistribution.R

Description

This methods calculates the degree distribution of a given graph.

Usage

1

Arguments

g

a graph as a graphNEL object.

deg

the distance matrix of the graph. If the parameter is empty the distance matrix will be calculated within the function.

Value

This methods returns the degree distribution

Author(s)

Laurin Mueller <laurin@eigenlab.net>

References

Skorobogatov V.A. and Dobrynin A.A., Metric analysis of graphs, match, pp. 105-151, 1988.

Examples

1
2
3
4
5
library(RBGL)
set.seed(123)
g <- randomGraph(1:8, 1:5, 0.36, weights=FALSE)

degreeDistribution(g)

Example output

Loading required package: graph
Loading required package: BiocGenerics
Loading required package: parallel

Attaching package: ‘BiocGenerics’

The following objects are masked from ‘package:parallel’:

    clusterApply, clusterApplyLB, clusterCall, clusterEvalQ,
    clusterExport, clusterMap, parApply, parCapply, parLapply,
    parLapplyLB, parRapply, parSapply, parSapplyLB

The following objects are masked from ‘package:stats’:

    IQR, mad, sd, var, xtabs

The following objects are masked from ‘package:base’:

    anyDuplicated, append, as.data.frame, basename, cbind, colnames,
    dirname, do.call, duplicated, eval, evalq, Filter, Find, get, grep,
    grepl, intersect, is.unsorted, lapply, Map, mapply, match, mget,
    order, paste, pmax, pmax.int, pmin, pmin.int, Position, rank,
    rbind, Reduce, rownames, sapply, setdiff, sort, table, tapply,
    union, unique, unsplit, which.max, which.min

Loading required package: RBGL
Loading required package: combinat

Attaching package: ‘combinat’

The following object is masked from ‘package:utils’:

    combn


Attaching package: ‘QuACN’

The following object is masked from ‘package:graph’:

    adjacencyMatrix

deg
3 4 5 7 
2 2 2 2 

QuACN documentation built on May 2, 2019, 5:46 p.m.